#!/usr/bin/Rscript

source("../lib/curve.r")
source("../lib/stats.r")
source("../lib/util.r")
source("../lib/eia.r")

# Main variables:
# pop - population
# tec - total energy consumption
# tco2 - total carbon dioxide emission
pop <- read.eia("../data/Population.csv")
tec <- read.eia("../data/Total Energy Use.csv")
tco2 <- read.eia("../data/Total Carbon Dioxide Emissions.csv")

# World population, et cetera
wpop <- colSums(pop, na.rm=T) / 1000
wtec <- colSums(tec, na.rm=T)
wtco2 <- colSums(tco2, na.rm=T) / 1000

# _np stands for "no projections"
wpop_np <- wpop
wtec_np <- wtec
wtco2_np <- wtco2
wpop_np <- wpop

# Projected population
yproj <- seq(2011, 2040)
wpopdel <- wpop[length(wpop)] - wpop[length(wpop)-1]
wpop_proj <- (yproj - 2010) * wpopdel + wpop["X2010"]
#wpop <- c(wpop, wpop_proj)
wpop_disp <- c(wpop, - seq(1,30) * seq(1,30) / 2000 + seq(1, 30) * wpopdel + wpop["X2010"])
wpop <- c(wpop, 7.66, 8.32, 8.87) # UN "medium variant"

# Projections are from the EIA report.

# Projected energy consumption
# 2010 - 510
# 2020 - 620
# 2030 - 730
# 2040 - 820
wtec <- c(wtec, 620, 730, 820)
wtec <- wtec * 0.0334334
wtec_np <- wtec_np * 0.0334334

# Projected CO2 emission
# 2010 - 31
# 2020 - 36
# 2030 - 41
# 2040 - 46
wtco2 <- c(wtco2, 36, 41, 46)

wecpc <- wtec / wpop
wco2pc <- wtco2 / wpop
carb <- wtco2 / wtec

wecpc_np <- wtec_np / wpop_np
wco2pc_np <- wtco2_np / wpop_np

years <- c(seq(1980, 2010), 2020, 2030, 2040)

# Write computed data to file
data <- data.frame(years, wpop, wtec, wtco2, wecpc, wco2pc, carb * 31.689, row.names=1)
colnames(data) <- c("World Population (Billions)",
		    "World Total Power Consumption (TeraWatts)",
		    "World Total CO2 Emissions (Billion Metric Tons per Year)",
		    "World Power Consumption per Billion Capita (TeraWatts)",
		    "World CO2 Emissions per Billion Capita (Billion Metric Tons per Year)",
		    "Carbon Intensity (Grams per MegaJoule)")
write.csv(data, "Figure 1.csv")

# Begin plotting
#################

pdf("Figure 1.pdf", width=11, height=7)

par(mar=c(4.5, 3.5, 3, 4)+0.1)
plot.new()
box()

col_t = "#ee0000"
col_p = "#0000ee"
popc <- "black"

legend("topleft",
       legend=c(expression("Power consumption per billion capita"),
		"CO"[2] ~ "Emissions per billion capita",
		"Total power consumption",
		"Total CO"[2] ~ "emissions",
		"CO"[2] ~ "intensity (emissions per unit energy)",
		expression("Human population")),
       lty=c(0, 0, 0, 0, 0, 1), lwd=1, pch=c(1, 4, 1, 4, 1, NA),
       col=c(col_p, col_p, col_t, col_t, "#006666", popc),
       cex=1.2)

# Population
par(yaxs="i")
plot.window(range(years), c(0, 4.6*max(wpop_np)))
lines(seq(1980, 2040), wpop_disp, col=popc, pch=20, cex=0.7)

text(1987, 5, "5 billion", col=popc, adj=c(0.5, 2.7), cex=1.4)
text(1999, 6, "6 billion", col=popc, adj=c(0.5, 2.7), cex=1.3)
text(2012, 7, "7 billion", col=popc, adj=c(0.5, 2.7), cex=1.4)
text(2027, 8, "8 billion", col=popc, adj=c(0.5, 2.7), cex=1.4)
arrows(1987, 5-1, 1987, 5 - .2, 0.05, col=popc)
arrows(1999, 6-1, 1999, 6 - .2, 0.05, col=popc)
arrows(2012, 7-1, 2012, 7 - .2, 0.05, col=popc)
arrows(2027, 8-1, 2027, 8 - .2, 0.05, col=popc)

title(main="Energy Use and Carbon Emissions",
      xlab="Year", cex.main=1.5, cex.lab=1.4)

text(2040, 0.3, "Energy data source: EIA", adj=c(1, -2), cex=1.4, font=1)
text(2040, 0.3, "Population projections: UN (medium scenario)", adj=c(1, -0.3), cex=1.4, font=1)

mtext("Power Consumption (TeraWatts)", side=2, line=2, cex=1.4)
mtext("CO"[2] ~ "Emissions (Billion Metric Tons per Year)", side=4, line=3, cex=1.4)

# Total Consumption
plot.window(range(years), c(0, 4*max(wtec_np)))
points(years, wtec, pch=1, col=col_t)
axis(side=2, at=seq(0, 30, 1), labels=F)
axis(side=2, at=seq(0, 30, 5), tck=-0.03, labels=F)
axis(side=2, at=seq(0, 30, 10), tck=-0.03)

# Total CO_2 (Million Metric Tons)
plot.window(range(years), c(0, 4*max(wtco2_np)))
points(years, wtco2, pch=4, col=col_t)
axis(side=4, at=seq(0, 50, 2), labels=F)
axis(side=4, at=seq(0, 50, 10), tck=-0.03)

# Consumption Per Capita
plot.window(range(years), c(0, 1.5*max(wecpc_np)))
points(years, wecpc, pch=1, col=col_p)
axis(side=2, at=seq(2.0, 3.4, 0.1), labels=F)
axis(side=2, at=seq(2.0, 3.4, 0.4), tck=-0.03)

# CO_2 Per Capita
plot.window(range(years), c(0, 1.5*max(wco2pc_np)))
points(years, wco2pc, pch=4, col=col_p)
axis(side=4, at=seq(3.4, 5.8, 0.1), labels=F)
axis(side=4, at=seq(3.4, 5.8, 0.4), tck=-0.03)

# Carbon Intensity
mcarb <- 60
plot.window(range(years), c(0, mcarb * 2))
points(years, carb * 31.689, pch=1, col="#005544")
abline(mcarb, 0, lty=2)
text(2040, mcarb, "60 grams per MegaJoule",
     adj=c(1, -0.3), cex=1.4, font=1)

axis(1, at=seq(1980, 2040, 1), labels=F)
axis(1, at=seq(1980, 2040, 5), tck=-0.03, labels=F)
axis(1, at=seq(1980, 2040, 10), tck=-0.03, labels=T, cex.axis=1.3)

