#!/usr/bin/Rscript

source("../lib/curve.r")
source("../lib/stats.r")
source("../lib/util.r")

# As with Figure 3a, we need a special list of exclusions to make the range of
# the plot be manageable. The excluded countries are all small-population.
exclude <- c("North America",
	     "Central & South America",
	     "Asia & Oceania",
	     "Europe",
	     "Eurasia",
	     "Africa",
	     "Middle East",
	     "Antarctica",
	     "Virgin Islands,  U.S.",
	     "Gibraltar",
	     "World")

read.eia <- function (n) {
	raw <- read.csv(n)
	rownames(raw) <- raw$Region
	return(raw[!(raw$Region %in% exclude),][!(names(raw) %in% "Region")])
}

pdf("Figure 6a.pdf")
par(mar=c(4.5, 4.5, 2.5, 0)+0.1)

# Main variables:
# pop - population
# tco2 - total carbon dioxide emission
# tco2pc - CO2 consumption per capita
pop <- read.eia("../data/Population.csv")
pop <- setNames(pop$X2010, rownames(pop)) * 1e6
tco2 <- read.eia("../data/Total Carbon Dioxide Emissions.csv")
tco2 <- setNames(tco2$X2010, rownames(tco2)) * 1000000
pop <- pop[order(names(pop))]
tco2 <- tco2[order(names(tco2))]
tco2 <- tco2[names(tco2) %in% names(pop)]

not.na <- !is.na(tco2) & !is.na(pop)
tco2 <- tco2[not.na]
pop <- pop[not.na]

tco2pc <- setNames(tco2/pop, names(tco2))
ord <- order(tco2pc)
tco2pc <- tco2pc[ord]
pop <- pop[ord]
ydata <- setNames(1-cumsum(pop)/sum(pop), names(pop))

# Write intermediate CSV data
data <- data.frame(tco2pc, ydata)
colnames(data) <- c("2010 CO2 emission per capita (Metric tons per year per capita)",
		    "2010 Cumulative fraction of world population")
write.csv(data, "Figure 6a.csv", row.names=F)

# Begin plotting
#################

plot(tco2pc, ydata,
     main="Cumulative Distribution of CO"[2] ~ "Emission",
     xlab="Metric Tons per Year per Capita",
     ylab="Fraction of World Population",
     xaxt="n", yaxt="n", cex.main=1.5, font.main=1,
     pch=20, type="o", cex=0.7, cex.lab=1.6, col="red")
axis(1, at=seq(0, 60, 5), tck=-0.03)
axis(1, at=0:60, labels=F)
axis(2, at=seq(0, 1, 0.2), tck=-0.03)
axis(2, at=seq(0, 1, 0.05), labels=F)
curve(1/exp(x/4.5), add=T, lty=2, col="black", lwd=1.5)

legend("topright",
       legend=c("2010 EIA data",
		"Exponential fit"),
       lty=c(1, 2), lwd=c(1, 1.5), pch=c(20, NA), col=c("red", "black"),
       cex=1.4)

par(col="blue")
text(tco2pc["United States"], ydata["United States"], "USA", adj=c(1, 1))
text(tco2pc["United Arab Emirates"],
     ydata["United Arab Emirates"], "UAE", adj=c(0.5, -0.3))
text(tco2pc["China"], ydata["China"], "CHN", adj=c(1.1, 1.1))
text(tco2pc["Pakistan"], ydata["Pakistan"], "PAK", adj=c(-0.1, -0.1))
text(tco2pc["India"], ydata["India"], "IND", adj=c(1.1, -0.1))
text(tco2pc["Brazil"], ydata["Brazil"], "BRA", adj=c(1.1, 1.1))
text(tco2pc["Russia"], ydata["Russia"], "RUS", adj=c(1.1, 1.1))
text(tco2pc["France"], ydata["France"], "FRA", adj=c(-0.1, -0.1))
text(tco2pc["Nigeria"], ydata["Nigeria"], "NGA", adj=c(-0.1, -0.1))
text(tco2pc["United Kingdom"],
     ydata["United Kingdom"], "UK", adj=c(1.1, 1.1))
interesting <- c("United States", "United Arab Emirates",
		 "China",
		 "Pakistan",
		 "India",
		 "Brazil",
		 "Russia",
		 "France",
		 "United Kingdom",
		 "Nigeria")
points(tco2pc[interesting], ydata[interesting], 
     xaxt="n", yaxt="n", cex.main=1.5, font.main=1,
     pch=20, type="p", cex=1.3, cex.lab=1.6, col="blue")

par(col="black")

temp <- sum(tco2)/sum(pop)
arrows(temp, 0.03, temp, -0.025, 0.1)
temp
text(-1.6, 0.03, "Average\n4.6 tonnes", adj=c(0, -0.05), cex=1.3)



# Inset

par(fig=c(0.25, 1, 0.2, 0.85), new=TRUE)
plot(tco2pc, ydata, xlab=NA, ylab=NA,
     xaxt="n", yaxt="n", cex.main=1.5, font.main=1,
     pch=20, type="o", cex=0.7, cex.lab=1.6, col="red", log="y")
axis(1, at=seq(0, 60, 5), tck=-0.05)
axis(1, at=0:60, labels=F)
axis(2, at=c(1, 0.1, 0.01, 0.001), labels=c("1", "0.1", "0.01", "0.001"), tck=-0.05)
axis(2, at=c(seq(0.1, 1, 0.1), seq(0.01, 0.1, 0.01), seq(0.001, 0.01, 0.001), seq(0.0001, 0.001, 0.0001)), labels=F)
curve(1/exp(x/4.5), add=T, lty=2, col="black", lwd=1.5)

par(col="blue")
text(tco2pc["United States"], ydata["United States"], "USA", adj=c(1.1, 1.1))
text(tco2pc["United Arab Emirates"],
     ydata["United Arab Emirates"], "UAE", adj=c(1.1, -0.3))
text(tco2pc["China"], ydata["China"], "CHN", adj=c(1.1, 1.1))
text(tco2pc["India"], ydata["India"], "IND", adj=c(-.1, -0.1))
text(tco2pc["Russia"], ydata["Russia"], "RUS", adj=c(1.1, 1.1))
text(tco2pc["France"], ydata["France"], "FRA", adj=c(-0.1, -0.1))
text(tco2pc["United Kingdom"],
     ydata["United Kingdom"], "UK", adj=c(1.1, 1.1))
interesting <- c("United States", "United Arab Emirates",
		 "China",
		 "India",
		 "Russia",
		 "France",
		 "United Kingdom")
points(tco2pc[interesting], ydata[interesting], 
     xaxt="n", yaxt="n", cex.main=1.5, font.main=1,
     pch=20, type="p", cex=1.2, cex.lab=1.6, col="blue")

